==> kubernetes-model-core-4.12.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/SecurityContextFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.lang.Long;
import java.lang.Object;
import java.util.Map;

public interface SecurityContextFluent<A extends SecurityContextFluent<A>> extends Fluent<A> {


    public Boolean isAllowPrivilegeEscalation();
    public A withAllowPrivilegeEscalation(Boolean allowPrivilegeEscalation);
    public Boolean hasAllowPrivilegeEscalation();
    public A withNewAllowPrivilegeEscalation(String arg1);
    public A withNewAllowPrivilegeEscalation(boolean arg1);
    
/**
 * This method has been deprecated, please use method buildCapabilities instead.
 * @return The buildable object.
 */
@Deprecated public Capabilities getCapabilities();
    public Capabilities buildCapabilities();
    public A withCapabilities(Capabilities capabilities);
    public Boolean hasCapabilities();
    public SecurityContextFluent.CapabilitiesNested<A> withNewCapabilities();
    public SecurityContextFluent.CapabilitiesNested<A> withNewCapabilitiesLike(Capabilities item);
    public SecurityContextFluent.CapabilitiesNested<A> editCapabilities();
    public SecurityContextFluent.CapabilitiesNested<A> editOrNewCapabilities();
    public SecurityContextFluent.CapabilitiesNested<A> editOrNewCapabilitiesLike(Capabilities item);
    public Boolean isPrivileged();
    public A withPrivileged(Boolean privileged);
    public Boolean hasPrivileged();
    public A withNewPrivileged(String arg1);
    public A withNewPrivileged(boolean arg1);
    public String getProcMount();
    public A withProcMount(String procMount);
    public Boolean hasProcMount();
    public A withNewProcMount(String arg1);
    public A withNewProcMount(StringBuilder arg1);
    public A withNewProcMount(StringBuffer arg1);
    public Boolean isReadOnlyRootFilesystem();
    public A withReadOnlyRootFilesystem(Boolean readOnlyRootFilesystem);
    public Boolean hasReadOnlyRootFilesystem();
    public A withNewReadOnlyRootFilesystem(String arg1);
    public A withNewReadOnlyRootFilesystem(boolean arg1);
    public Long getRunAsGroup();
    public A withRunAsGroup(Long runAsGroup);
    public Boolean hasRunAsGroup();
    public Boolean isRunAsNonRoot();
    public A withRunAsNonRoot(Boolean runAsNonRoot);
    public Boolean hasRunAsNonRoot();
    public A withNewRunAsNonRoot(String arg1);
    public A withNewRunAsNonRoot(boolean arg1);
    public Long getRunAsUser();
    public A withRunAsUser(Long runAsUser);
    public Boolean hasRunAsUser();
    
/**
 * This method has been deprecated, please use method buildSeLinuxOptions instead.
 * @return The buildable object.
 */
@Deprecated public SELinuxOptions getSeLinuxOptions();
    public SELinuxOptions buildSeLinuxOptions();
    public A withSeLinuxOptions(SELinuxOptions seLinuxOptions);
    public Boolean hasSeLinuxOptions();
    public A withNewSeLinuxOptions(String level,String role,String type,String user);
    public SecurityContextFluent.SeLinuxOptionsNested<A> withNewSeLinuxOptions();
    public SecurityContextFluent.SeLinuxOptionsNested<A> withNewSeLinuxOptionsLike(SELinuxOptions item);
    public SecurityContextFluent.SeLinuxOptionsNested<A> editSeLinuxOptions();
    public SecurityContextFluent.SeLinuxOptionsNested<A> editOrNewSeLinuxOptions();
    public SecurityContextFluent.SeLinuxOptionsNested<A> editOrNewSeLinuxOptionsLike(SELinuxOptions item);
    
/**
 * This method has been deprecated, please use method buildWindowsOptions instead.
 * @return The buildable object.
 */
@Deprecated public WindowsSecurityContextOptions getWindowsOptions();
    public WindowsSecurityContextOptions buildWindowsOptions();
    public A withWindowsOptions(WindowsSecurityContextOptions windowsOptions);
    public Boolean hasWindowsOptions();
    public A withNewWindowsOptions(String gmsaCredentialSpec,String gmsaCredentialSpecName,String runAsUserName);
    public SecurityContextFluent.WindowsOptionsNested<A> withNewWindowsOptions();
    public SecurityContextFluent.WindowsOptionsNested<A> withNewWindowsOptionsLike(WindowsSecurityContextOptions item);
    public SecurityContextFluent.WindowsOptionsNested<A> editWindowsOptions();
    public SecurityContextFluent.WindowsOptionsNested<A> editOrNewWindowsOptions();
    public SecurityContextFluent.WindowsOptionsNested<A> editOrNewWindowsOptionsLike(WindowsSecurityContextOptions item);
    public interface CapabilitiesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CapabilitiesFluent<SecurityContextFluent.CapabilitiesNested<N>> {

        public N and();
        public N endCapabilities();    }


    public interface SeLinuxOptionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SELinuxOptionsFluent<SecurityContextFluent.SeLinuxOptionsNested<N>> {

        public N and();
        public N endSeLinuxOptions();    }


    public interface WindowsOptionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,WindowsSecurityContextOptionsFluent<SecurityContextFluent.WindowsOptionsNested<N>> {

        public N and();
        public N endWindowsOptions();    }


}

==> kubernetes-model-core-4.13.3-sources.jar: annotations/io/fabric8/kubernetes/api/model/SecurityContextFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.lang.Long;
import java.lang.Object;
import java.util.Map;

public interface SecurityContextFluent<A extends SecurityContextFluent<A>> extends Fluent<A> {


    public Boolean isAllowPrivilegeEscalation();
    public A withAllowPrivilegeEscalation(Boolean allowPrivilegeEscalation);
    public Boolean hasAllowPrivilegeEscalation();
    public A withNewAllowPrivilegeEscalation(String arg1);
    public A withNewAllowPrivilegeEscalation(boolean arg1);
    
/**
 * This method has been deprecated, please use method buildCapabilities instead.
 * @return The buildable object.
 */
@Deprecated public Capabilities getCapabilities();
    public Capabilities buildCapabilities();
    public A withCapabilities(Capabilities capabilities);
    public Boolean hasCapabilities();
    public SecurityContextFluent.CapabilitiesNested<A> withNewCapabilities();
    public SecurityContextFluent.CapabilitiesNested<A> withNewCapabilitiesLike(Capabilities item);
    public SecurityContextFluent.CapabilitiesNested<A> editCapabilities();
    public SecurityContextFluent.CapabilitiesNested<A> editOrNewCapabilities();
    public SecurityContextFluent.CapabilitiesNested<A> editOrNewCapabilitiesLike(Capabilities item);
    public Boolean isPrivileged();
    public A withPrivileged(Boolean privileged);
    public Boolean hasPrivileged();
    public A withNewPrivileged(String arg1);
    public A withNewPrivileged(boolean arg1);
    public String getProcMount();
    public A withProcMount(String procMount);
    public Boolean hasProcMount();
    public A withNewProcMount(String arg1);
    public A withNewProcMount(StringBuilder arg1);
    public A withNewProcMount(StringBuffer arg1);
    public Boolean isReadOnlyRootFilesystem();
    public A withReadOnlyRootFilesystem(Boolean readOnlyRootFilesystem);
    public Boolean hasReadOnlyRootFilesystem();
    public A withNewReadOnlyRootFilesystem(String arg1);
    public A withNewReadOnlyRootFilesystem(boolean arg1);
    public Long getRunAsGroup();
    public A withRunAsGroup(Long runAsGroup);
    public Boolean hasRunAsGroup();
    public Boolean isRunAsNonRoot();
    public A withRunAsNonRoot(Boolean runAsNonRoot);
    public Boolean hasRunAsNonRoot();
    public A withNewRunAsNonRoot(String arg1);
    public A withNewRunAsNonRoot(boolean arg1);
    public Long getRunAsUser();
    public A withRunAsUser(Long runAsUser);
    public Boolean hasRunAsUser();
    
/**
 * This method has been deprecated, please use method buildSeLinuxOptions instead.
 * @return The buildable object.
 */
@Deprecated public SELinuxOptions getSeLinuxOptions();
    public SELinuxOptions buildSeLinuxOptions();
    public A withSeLinuxOptions(SELinuxOptions seLinuxOptions);
    public Boolean hasSeLinuxOptions();
    public A withNewSeLinuxOptions(String level,String role,String type,String user);
    public SecurityContextFluent.SeLinuxOptionsNested<A> withNewSeLinuxOptions();
    public SecurityContextFluent.SeLinuxOptionsNested<A> withNewSeLinuxOptionsLike(SELinuxOptions item);
    public SecurityContextFluent.SeLinuxOptionsNested<A> editSeLinuxOptions();
    public SecurityContextFluent.SeLinuxOptionsNested<A> editOrNewSeLinuxOptions();
    public SecurityContextFluent.SeLinuxOptionsNested<A> editOrNewSeLinuxOptionsLike(SELinuxOptions item);
    
/**
 * This method has been deprecated, please use method buildSeccompProfile instead.
 * @return The buildable object.
 */
@Deprecated public SeccompProfile getSeccompProfile();
    public SeccompProfile buildSeccompProfile();
    public A withSeccompProfile(SeccompProfile seccompProfile);
    public Boolean hasSeccompProfile();
    public A withNewSeccompProfile(String localhostProfile,String type);
    public SecurityContextFluent.SeccompProfileNested<A> withNewSeccompProfile();
    public SecurityContextFluent.SeccompProfileNested<A> withNewSeccompProfileLike(SeccompProfile item);
    public SecurityContextFluent.SeccompProfileNested<A> editSeccompProfile();
    public SecurityContextFluent.SeccompProfileNested<A> editOrNewSeccompProfile();
    public SecurityContextFluent.SeccompProfileNested<A> editOrNewSeccompProfileLike(SeccompProfile item);
    
/**
 * This method has been deprecated, please use method buildWindowsOptions instead.
 * @return The buildable object.
 */
@Deprecated public WindowsSecurityContextOptions getWindowsOptions();
    public WindowsSecurityContextOptions buildWindowsOptions();
    public A withWindowsOptions(WindowsSecurityContextOptions windowsOptions);
    public Boolean hasWindowsOptions();
    public A withNewWindowsOptions(String gmsaCredentialSpec,String gmsaCredentialSpecName,String runAsUserName);
    public SecurityContextFluent.WindowsOptionsNested<A> withNewWindowsOptions();
    public SecurityContextFluent.WindowsOptionsNested<A> withNewWindowsOptionsLike(WindowsSecurityContextOptions item);
    public SecurityContextFluent.WindowsOptionsNested<A> editWindowsOptions();
    public SecurityContextFluent.WindowsOptionsNested<A> editOrNewWindowsOptions();
    public SecurityContextFluent.WindowsOptionsNested<A> editOrNewWindowsOptionsLike(WindowsSecurityContextOptions item);
    public interface CapabilitiesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CapabilitiesFluent<SecurityContextFluent.CapabilitiesNested<N>> {

        public N and();
        public N endCapabilities();    }


    public interface SeLinuxOptionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SELinuxOptionsFluent<SecurityContextFluent.SeLinuxOptionsNested<N>> {

        public N and();
        public N endSeLinuxOptions();    }


    public interface SeccompProfileNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SeccompProfileFluent<SecurityContextFluent.SeccompProfileNested<N>> {

        public N and();
        public N endSeccompProfile();    }


    public interface WindowsOptionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,WindowsSecurityContextOptionsFluent<SecurityContextFluent.WindowsOptionsNested<N>> {

        public N and();
        public N endWindowsOptions();    }


}
